#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=thera4.19_base.ps
projection=-JM16.0c+
region=-R25.4/26.1/36.2/36.9
gmt psbasemap $region $projection -Bxa0.2f0.1 -Bya0.2f0.1 -BWeSn+t'Base Map thera4.19' -K > $psfile

# Standard Topography (ETOPO1)
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m_g -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd

# Coastlines and rivers
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile

# Event numbers
gmt psxy -: -R $projection -Sl8p+t"1" -G0 -O -K << END >> $psfile
    36.495    25.780
END
gmt psxy -: -R $projection -Sl8p+t"2" -G0 -O -K << END >> $psfile
    36.630    25.713
END
gmt psxy -: -R $projection -Sl8p+t"3" -G0 -O -K << END >> $psfile
    36.833    25.829
END
gmt psxy -: -R $projection -Sl8p+t"4" -G0 -O -K << END >> $psfile
    36.508    25.806
END
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    36.603    25.885
END
gmt psxy -: -R $projection -Sl8p+t"6" -G0 -O -K << END >> $psfile
    36.582    25.683
END
gmt psxy -: -R $projection -Sl8p+t"7" -G0 -O -K << END >> $psfile
    36.641    25.761
END
gmt psxy -: -R $projection -Sl8p+t"8" -G0 -O -K << END >> $psfile
    36.614    25.734
END
gmt psxy -: -R $projection -Sl8p+t"9" -G0 -O -K << END >> $psfile
    36.702    25.888
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    36.739    25.900
END
gmt psxy -: -R $projection -Sl8p+t"11" -G0 -O -K << END >> $psfile
    36.672    25.646
END
gmt psxy -: -R $projection -Sl8p+t"12" -G0 -O -K << END >> $psfile
    36.630    25.649
END
gmt psxy -: -R $projection -Sl8p+t"13" -G0 -O -K << END >> $psfile
    36.529    25.516
END
gmt psxy -: -R $projection -Sl8p+t"14" -G0 -O -K << END >> $psfile
    36.500    25.504
END
gmt psxy -: -R $projection -Sl8p+t"15" -G0 -O -K << END >> $psfile
    36.517    25.499
END
gmt psxy -: -R $projection -Sl8p+t"16" -G0 -O -K << END >> $psfile
    36.596    25.637
END
gmt psxy -: -R $projection -Sl8p+t"17" -G0 -O -K << END >> $psfile
    36.615    25.595
END
gmt psxy -: -R $projection -Sl8p+t"18" -G0 -O -K << END >> $psfile
    36.524    25.484
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    36.565    25.509
END
gmt psxy -: -R $projection -Sl8p+t"20" -G0 -O -K << END >> $psfile
    36.703    25.744
END
gmt psxy -: -R $projection -Sl8p+t"21" -G0 -O -K << END >> $psfile
    36.542    25.488
END
gmt psxy -: -R $projection -Sl8p+t"22" -G0 -O -K << END >> $psfile
    36.642    25.818
END
gmt psxy -: -R $projection -Sl8p+t"23" -G0 -O -K << END >> $psfile
    36.661    25.868
END
gmt psxy -: -R $projection -Sl8p+t"24" -G0 -O -K << END >> $psfile
    36.545    25.498
END
gmt psxy -: -R $projection -Sl8p+t"25" -G0 -O -K << END >> $psfile
    36.530    25.492
END
gmt psxy -: -R $projection -Sl8p+t"26" -G0 -O -K << END >> $psfile
    36.707    25.979
END
gmt psxy -: -R $projection -Sl8p+t"27" -G0 -O -K << END >> $psfile
    36.511    25.498
END
gmt psxy -: -R $projection -Sl8p+t"28" -G0 -O -K << END >> $psfile
    36.537    25.502
END
gmt psxy -: -R $projection -Sl8p+t"29" -G0 -O -K << END >> $psfile
    36.692    25.656
END
gmt psxy -: -R $projection -Sl8p+t"30" -G0 -O -K << END >> $psfile
    36.521    25.495
END
gmt psxy -: -R $projection -Sl8p+t"31" -G0 -O -K << END >> $psfile
    36.520    25.506
END
gmt psxy -: -R $projection -Sl8p+t"32" -G0 -O -K << END >> $psfile
    36.529    25.506
END
gmt psxy -: -R $projection -Sl8p+t"33" -G0 -O -K << END >> $psfile
    36.531    25.508
END
gmt psxy -: -R $projection -Sl8p+t"34" -G0 -O -K << END >> $psfile
    36.521    25.479
END
gmt psxy -: -R $projection -Sl8p+t"35" -G0 -O -K << END >> $psfile
    36.547    25.523
END
gmt psxy -: -R $projection -Sl8p+t"36" -G0 -O -K << END >> $psfile
    36.536    25.533
END
gmt psxy -: -R $projection -Sl8p+t"37" -G0 -O -K << END >> $psfile
    36.540    25.511
END
gmt psxy -: -R $projection -Sl8p+t"38" -G0 -O -K << END >> $psfile
    36.542    25.510
END
gmt psxy -: -R $projection -Sl8p+t"39" -G0 -O -K << END >> $psfile
    36.548    25.491
END
gmt psxy -: -R $projection -Sl8p+t"40" -G0 -O -K << END >> $psfile
    36.608    25.678
END
gmt psxy -: -R $projection -Sl8p+t"41" -G0 -O -K << END >> $psfile
    36.689    25.755
END
gmt psxy -: -R $projection -Sl8p+t"42" -G0 -O -K << END >> $psfile
    36.636    25.713
END
gmt psxy -: -R $projection -Sl8p+t"43" -G0 -O -K << END >> $psfile
    36.693    25.738
END
gmt psxy -: -R $projection -Sl8p+t"44" -G0 -O -K << END >> $psfile
    36.690    25.913
END
gmt psxy -: -R $projection -Sl8p+t"45" -G0 -O -K << END >> $psfile
    36.521    25.500
END
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    36.618    25.701
END
gmt psxy -: -R $projection -Sl8p+t"47" -G0 -O -K << END >> $psfile
    36.610    25.730
END
gmt psxy -: -R $projection -Sl8p+t"48" -G0 -O -K << END >> $psfile
    36.611    25.708
END
gmt psxy -: -R $projection -Sl8p+t"49" -G0 -O -K << END >> $psfile
    36.533    25.536
END
gmt psxy -: -R $projection -Sl8p+t"50" -G0 -O -K << END >> $psfile
    36.541    25.501
END
gmt psxy -: -R $projection -Sl8p+t"51" -G0 -O -K << END >> $psfile
    36.599    25.605
END
gmt psxy -: -R $projection -Sl8p+t"52" -G0 -O -K << END >> $psfile
    36.587    25.704
END
gmt psxy -: -R $projection -Sl8p+t"53" -G0 -O -K << END >> $psfile
    36.603    25.676
END
gmt psxy -: -R $projection -Sl8p+t"54" -G0 -O -K << END >> $psfile
    36.724    25.632
END
gmt psxy -: -R $projection -Sl8p+t"55" -G0 -O -K << END >> $psfile
    36.600    25.693
END
gmt psxy -: -R $projection -Sl8p+t"56" -G0 -O -K << END >> $psfile
    36.580    25.683
END
gmt psxy -: -R $projection -Sl8p+t"57" -G0 -O -K << END >> $psfile
    36.656    25.737
END
gmt psxy -: -R $projection -Sl8p+t"58" -G0 -O -K << END >> $psfile
    36.651    25.765
END
gmt psxy -: -R $projection -Sl8p+t"59" -G0 -O -K << END >> $psfile
    36.659    25.735
END
gmt psxy -: -R $projection -Sl8p+t"60" -G0 -O -K << END >> $psfile
    36.655    25.772
END
gmt psxy -: -R $projection -Sl8p+t"61" -G0 -O -K << END >> $psfile
    36.663    25.768
END
gmt psxy -: -R $projection -Sl8p+t"62" -G0 -O -K << END >> $psfile
    36.656    25.767
END
gmt psxy -: -R $projection -Sl8p+t"63" -G0 -O -K << END >> $psfile
    36.660    25.764
END
gmt psxy -: -R $projection -Sl8p+t"64" -G0 -O -K << END >> $psfile
    36.668    25.759
END
gmt psxy -: -R $projection -Sl8p+t"65" -G0 -O -K << END >> $psfile
    36.669    25.746
END
gmt psxy -: -R $projection -Sl8p+t"66" -G0 -O -K << END >> $psfile
    36.658    25.747
END
gmt psxy -: -R $projection -Sl8p+t"67" -G0 -O -K << END >> $psfile
    36.697    25.610
END
gmt psxy -: -R $projection -Sl8p+t"68" -G0 -O -K << END >> $psfile
    36.679    25.643
END
gmt psxy -: -R $projection -Sl8p+t"69" -G0 -O -K << END >> $psfile
    36.694    25.681
END
gmt psxy -: -R $projection -Sl8p+t"70" -G0 -O -K << END >> $psfile
    36.585    25.696
END
gmt psxy -: -R $projection -Sl8p+t"71" -G0 -O -K << END >> $psfile
    36.502    25.768
END
gmt psxy -: -R $projection -Sl8p+t"72" -G0 -O -K << END >> $psfile
    36.522    25.709
END
gmt psxy -: -R $projection -Sl8p+t"73" -G0 -O -K << END >> $psfile
    36.295    25.672
END
gmt psxy -: -R $projection -Sl8p+t"74" -G0 -O -K << END >> $psfile
    36.284    25.639
END
gmt psxy -: -R $projection -Sl8p+t"75" -G0 -O -K << END >> $psfile
    36.298    25.628
END
gmt psxy -: -R $projection -Sl8p+t"76" -G0 -O -K << END >> $psfile
    36.475    25.785
END
gmt psxy -: -R $projection -Sl8p+t"77" -G0 -O -K << END >> $psfile
    36.267    25.616
END
gmt psxy -: -R $projection -Sl8p+t"78" -G0 -O -K << END >> $psfile
    36.525    25.479
END
gmt psxy -: -R $projection -Sl8p+t"79" -G0 -O -K << END >> $psfile
    36.473    25.533
END
gmt psxy -: -R $projection -Sl8p+t"80" -G0 -O -K << END >> $psfile
    36.603    25.606
END
gmt psxy -: -R $projection -Sl8p+t"81" -G0 -O -K << END >> $psfile
    36.531    25.496
END
gmt psxy -: -R $projection -Sl8p+t"82" -G0 -O -K << END >> $psfile
    36.549    25.506
END
gmt psxy -: -R $projection -Sl8p+t"83" -G0 -O -K << END >> $psfile
    36.510    25.511
END
gmt psxy -: -R $projection -Sl8p+t"84" -G0 -O -K << END >> $psfile
    36.526    25.529
END
gmt psxy -: -R $projection -Sl8p+t"85" -G0 -O -K << END >> $psfile
    36.539    25.499
END
gmt psxy -: -R $projection -Sl8p+t"86" -G0 -O -K << END >> $psfile
    36.528    25.516
END
gmt psxy -: -R $projection -Sl8p+t"87" -G0 -O -K << END >> $psfile
    36.538    25.506
END
gmt psxy -: -R $projection -Sl8p+t"88" -G0 -O -K << END >> $psfile
    36.504    25.505
END
gmt psxy -: -R $projection -Sl8p+t"89" -G0 -O -K << END >> $psfile
    36.525    25.454
END
gmt psxy -: -R $projection -Sl8p+t"90" -G0 -O -K << END >> $psfile
    36.617    25.728
END
gmt psxy -: -R $projection -Sl8p+t"91" -G0 -O -K << END >> $psfile
    36.512    25.516
END
gmt psxy -: -R $projection -Sl8p+t"92" -G0 -O -K << END >> $psfile
    36.267    25.643
END
gmt psxy -: -R $projection -Sl8p+t"93" -G0 -O -K << END >> $psfile
    36.652    25.658
END
gmt psxy -: -R $projection -Sl8p+t"94" -G0 -O -K << END >> $psfile
    36.646    25.631
END
gmt psxy -: -R $projection -Sl8p+t"95" -G0 -O -K << END >> $psfile
    36.604    25.615
END
gmt psxy -: -R $projection -Sl8p+t"96" -G0 -O -K << END >> $psfile
    36.604    25.674
END
gmt psxy -: -R $projection -Sl8p+t"97" -G0 -O -K << END >> $psfile
    36.593    25.666
END
gmt psxy -: -R $projection -Sl8p+t"98" -G0 -O -K << END >> $psfile
    36.624    25.723
END
gmt psxy -: -R $projection -Sl8p+t"99" -G0 -O -K << END >> $psfile
    36.622    25.696
END
gmt psxy -: -R $projection -Sl8p+t" 100" -G0 -O -K << END >> $psfile
    36.600    25.715
END
gmt psxy -: -R $projection -Sl8p+t" 101" -G0 -O -K << END >> $psfile
    36.611    25.700
END
gmt psxy -: -R $projection -Sl8p+t" 102" -G0 -O -K << END >> $psfile
    36.605    25.735
END
gmt psxy -: -R $projection -Sl8p+t" 103" -G0 -O -K << END >> $psfile
    36.588    25.722
END
gmt psxy -: -R $projection -Sl8p+t" 104" -G0 -O -K << END >> $psfile
    36.614    25.706
END
gmt psxy -: -R $projection -Sl8p+t" 105" -G0 -O -K << END >> $psfile
    36.595    25.750
END
gmt psxy -: -R $projection -Sl8p+t" 106" -G0 -O -K << END >> $psfile
    36.600    25.691
END
gmt psxy -: -R $projection -Sl8p+t" 107" -G0 -O -K << END >> $psfile
    36.598    25.720
END
gmt psxy -: -R $projection -Sl8p+t" 108" -G0 -O -K << END >> $psfile
    36.627    25.744
END
gmt psxy -: -R $projection -Sl8p+t" 109" -G0 -O -K << END >> $psfile
    36.616    25.747
END
gmt psxy -: -R $projection -Sl8p+t" 110" -G0 -O -K << END >> $psfile
    36.614    25.692
END
gmt psxy -: -R $projection -Sl8p+t" 111" -G0 -O -K << END >> $psfile
    36.616    25.700
END
gmt psxy -: -R $projection -Sl8p+t" 112" -G0 -O -K << END >> $psfile
    36.598    25.691
END
gmt psxy -: -R $projection -Sl8p+t" 113" -G0 -O -K << END >> $psfile
    36.630    25.711
END
gmt psxy -: -R $projection -Sl8p+t" 114" -G0 -O -K << END >> $psfile
    36.644    25.718
END
gmt psxy -: -R $projection -Sl8p+t" 115" -G0 -O -K << END >> $psfile
    36.650    25.764
END
gmt psxy -: -R $projection -Sl8p+t" 116" -G0 -O -K << END >> $psfile
    36.652    25.695
END
gmt psxy -: -R $projection -Sl8p+t" 117" -G0 -O -K << END >> $psfile
    36.666    25.759
END
gmt psxy -: -R $projection -Sl8p+t" 118" -G0 -O -K << END >> $psfile
    36.642    25.767
END
gmt psxy -: -R $projection -Sl8p+t" 119" -G0 -O -K << END >> $psfile
    36.621    25.725
END
gmt psxy -: -R $projection -Sl8p+t" 120" -G0 -O -K << END >> $psfile
    36.616    25.710
END
gmt psxy -: -R $projection -Sl8p+t" 121" -G0 -O -K << END >> $psfile
    36.628    25.694
END
gmt psxy -: -R $projection -Sl8p+t" 122" -G0 -O -K << END >> $psfile
    36.630    25.729
END
gmt psxy -: -R $projection -Sl8p+t" 123" -G0 -O -K << END >> $psfile
    36.642    25.746
END
gmt psxy -: -R $projection -Sl8p+t" 124" -G0 -O -K << END >> $psfile
    36.653    25.723
END
gmt psxy -: -R $projection -Sl8p+t" 125" -G0 -O -K << END >> $psfile
    36.652    25.773
END
gmt psxy -: -R $projection -Sl8p+t" 126" -G0 -O -K << END >> $psfile
    36.666    25.713
END
gmt psxy -: -R $projection -Sl8p+t" 127" -G0 -O -K << END >> $psfile
    36.599    25.675
END
gmt psxy -: -R $projection -Sl8p+t" 128" -G0 -O -K << END >> $psfile
    36.591    25.676
END
gmt psxy -: -R $projection -Sl8p+t" 129" -G0 -O -K << END >> $psfile
    36.612    25.656
END
gmt psxy -: -R $projection -Sl8p+t" 130" -G0 -O -K << END >> $psfile
    36.615    25.699
END
gmt psxy -: -R $projection -Sl8p+t" 131" -G0 -O -K << END >> $psfile
    36.631    25.793
END
gmt psxy -: -R $projection -Sl8p+t" 132" -G0 -O -K << END >> $psfile
    36.655    25.744
END
gmt psxy -: -R $projection -Sl8p+t" 133" -G0 -O -K << END >> $psfile
    36.653    25.773
END
gmt psxy -: -R $projection -Sl8p+t" 134" -G0 -O -K << END >> $psfile
    36.650    25.790
END
gmt psxy -: -R $projection -Sl8p+t" 135" -G0 -O -K << END >> $psfile
    36.679    25.719
END
gmt psxy -: -R $projection -Sl8p+t" 136" -G0 -O -K << END >> $psfile
    36.641    25.715
END
gmt psxy -: -R $projection -Sl8p+t" 137" -G0 -O -K << END >> $psfile
    36.639    25.723
END
gmt psxy -: -R $projection -Sl8p+t" 138" -G0 -O -K << END >> $psfile
    36.649    25.772
END
gmt psxy -: -R $projection -Sl8p+t" 139" -G0 -O -K << END >> $psfile
    36.645    25.736
END
gmt psxy -: -R $projection -Sl8p+t" 140" -G0 -O -K << END >> $psfile
    36.633    25.711
END
gmt psxy -: -R $projection -Sl8p+t" 141" -G0 -O -K << END >> $psfile
    36.662    25.793
END
gmt psxy -: -R $projection -Sl8p+t" 142" -G0 -O -K << END >> $psfile
    36.659    25.780
END
gmt psxy -: -R $projection -Sl8p+t" 143" -G0 -O -K << END >> $psfile
    36.596    25.690
END
gmt psxy -: -R $projection -Sl8p+t" 144" -G0 -O -K << END >> $psfile
    36.596    25.619
END
gmt psxy -: -R $projection -Sl8p+t" 145" -G0 -O -K << END >> $psfile
    36.602    25.692
END
gmt psxy -: -R $projection -Sl8p+t" 146" -G0 -O -K << END >> $psfile
    36.616    25.698
END
gmt psxy -: -R $projection -Sl8p+t" 147" -G0 -O -K << END >> $psfile
    36.588    25.693
END
gmt psxy -: -R $projection -Sl8p+t" 148" -G0 -O -K << END >> $psfile
    36.605    25.693
END
gmt psxy -: -R $projection -Sl8p+t" 149" -G0 -O -K << END >> $psfile
    36.603    25.667
END
gmt psxy -: -R $projection -Sl8p+t" 150" -G0 -O -K << END >> $psfile
    36.612    25.688
END
gmt psxy -: -R $projection -Sl8p+t" 151" -G0 -O -K << END >> $psfile
    36.625    25.618
END
gmt psxy -: -R $projection -Sl8p+t" 152" -G0 -O -K << END >> $psfile
    36.610    25.690
END
gmt psxy -: -R $projection -Sl8p+t" 153" -G0 -O -K << END >> $psfile
    36.595    25.643
END
gmt psxy -: -R $projection -Sl8p+t" 154" -G0 -O -K << END >> $psfile
    36.602    25.713
END
gmt psxy -: -R $projection -Sl8p+t" 155" -G0 -O -K << END >> $psfile
    36.595    25.773
END
gmt psxy -: -R $projection -Sl8p+t" 156" -G0 -O -K << END >> $psfile
    36.584    25.626
END
gmt psxy -: -R $projection -Sl8p+t" 157" -G0 -O -K << END >> $psfile
    36.636    25.780
END
gmt psxy -: -R $projection -Sl8p+t" 158" -G0 -O -K << END >> $psfile
    36.532    25.616
END

# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.492    25.783
    36.495    25.780
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.385    25.866
    36.495    25.780
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.624    25.714
    36.630    25.713
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.593    25.861
    36.630    25.713
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.832    25.834
    36.833    25.829
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.622    25.787
    36.833    25.829
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.506    25.813
    36.508    25.806
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.227    25.867
    36.508    25.806
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.604    25.890
    36.603    25.885
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.572    25.828
    36.603    25.885
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.581    25.683
    36.582    25.683
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.510    25.736
    36.582    25.683
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.641    25.764
    36.641    25.761
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.579    25.697
    36.641    25.761
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.615    25.737
    36.614    25.734
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.623    25.696
    36.614    25.734
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.702    25.889
    36.702    25.888
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.573    25.740
    36.702    25.888
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.738    25.902
    36.739    25.900
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.660    25.834
    36.739    25.900
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.670    25.643
    36.672    25.646
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.607    25.679
    36.672    25.646
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.630    25.652
    36.630    25.649
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.588    25.671
    36.630    25.649
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.528    25.517
    36.529    25.516
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.518    25.575
    36.529    25.516
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.501    25.505
    36.500    25.504
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.473    25.567
    36.500    25.504
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.517    25.500
    36.517    25.499
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.455    25.475
    36.517    25.499
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.596    25.638
    36.596    25.637
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.569    25.703
    36.596    25.637
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.615    25.595
    36.615    25.595
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.538    25.585
    36.615    25.595
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.524    25.486
    36.524    25.484
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.515    25.481
    36.524    25.484
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.564    25.509
    36.565    25.509
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.474    25.531
    36.565    25.509
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.700    25.746
    36.703    25.744
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.659    25.715
    36.703    25.744
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.542    25.489
    36.542    25.488
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.521    25.473
    36.542    25.488
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.641    25.818
    36.642    25.818
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.568    25.821
    36.642    25.818
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.661    25.869
    36.661    25.868
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.610    25.800
    36.661    25.868
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.545    25.499
    36.545    25.498
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.521    25.551
    36.545    25.498
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.530    25.491
    36.530    25.492
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.546    25.411
    36.530    25.492
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.708    25.980
    36.707    25.979
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.644    25.824
    36.707    25.979
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.511    25.498
    36.511    25.498
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.453    25.519
    36.511    25.498
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.537    25.502
    36.537    25.502
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.528    25.522
    36.537    25.502
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.692    25.658
    36.692    25.656
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.672    25.660
    36.692    25.656
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.521    25.496
    36.521    25.495
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.498    25.491
    36.521    25.495
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.520    25.507
    36.520    25.506
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.510    25.505
    36.520    25.506
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.529    25.507
    36.529    25.506
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.504    25.497
    36.529    25.506
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.531    25.509
    36.531    25.508
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.531    25.532
    36.531    25.508
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.521    25.480
    36.521    25.479
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.527    25.449
    36.521    25.479
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.547    25.525
    36.547    25.523
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.535    25.507
    36.547    25.523
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.536    25.534
    36.536    25.533
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.524    25.553
    36.536    25.533
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.540    25.512
    36.540    25.511
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.519    25.484
    36.540    25.511
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.542    25.512
    36.542    25.510
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.546    25.454
    36.542    25.510
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.549    25.492
    36.548    25.491
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.530    25.478
    36.548    25.491
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.608    25.678
    36.608    25.678
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.591    25.691
    36.608    25.678
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.689    25.760
    36.689    25.755
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.659    25.769
    36.689    25.755
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.635    25.714
    36.636    25.713
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.590    25.724
    36.636    25.713
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.693    25.739
    36.693    25.738
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.684    25.690
    36.693    25.738
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.690    25.911
    36.690    25.913
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.688    25.869
    36.690    25.913
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.521    25.500
    36.521    25.500
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.504    25.460
    36.521    25.500
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.618    25.702
    36.618    25.701
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.605    25.676
    36.618    25.701
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.610    25.730
    36.610    25.730
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.600    25.722
    36.610    25.730
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.611    25.708
    36.611    25.708
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.604    25.711
    36.611    25.708
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.533    25.537
    36.533    25.536
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.516    25.497
    36.533    25.536
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.541    25.502
    36.541    25.501
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.528    25.449
    36.541    25.501
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.599    25.605
    36.599    25.605
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.557    25.528
    36.599    25.605
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.586    25.706
    36.587    25.704
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.540    25.658
    36.587    25.704
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.603    25.676
    36.603    25.676
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.606    25.708
    36.603    25.676
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.723    25.633
    36.724    25.632
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.724    25.619
    36.724    25.632
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.600    25.694
    36.600    25.693
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.600    25.676
    36.600    25.693
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.579    25.684
    36.580    25.683
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.609    25.639
    36.580    25.683
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.656    25.737
    36.656    25.737
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.573    25.729
    36.656    25.737
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.650    25.766
    36.651    25.765
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.634    25.684
    36.651    25.765
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.659    25.736
    36.659    25.735
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.677    25.729
    36.659    25.735
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.656    25.772
    36.655    25.772
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.645    25.742
    36.655    25.772
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.663    25.769
    36.663    25.768
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.644    25.751
    36.663    25.768
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.656    25.768
    36.656    25.767
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.616    25.754
    36.656    25.767
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.660    25.765
    36.660    25.764
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.670    25.755
    36.660    25.764
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.668    25.760
    36.668    25.759
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.658    25.744
    36.668    25.759
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.669    25.746
    36.669    25.746
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.678    25.726
    36.669    25.746
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.658    25.748
    36.658    25.747
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.694    25.708
    36.658    25.747
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.697    25.610
    36.697    25.610
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.724    25.620
    36.697    25.610
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.680    25.642
    36.679    25.643
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.715    25.621
    36.679    25.643
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.694    25.682
    36.694    25.681
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.672    25.644
    36.694    25.681
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.585    25.698
    36.585    25.696
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.606    25.708
    36.585    25.696
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.502    25.768
    36.502    25.768
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.481    25.744
    36.502    25.768
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.522    25.709
    36.522    25.709
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.482    25.683
    36.522    25.709
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.295    25.671
    36.295    25.672
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.243    25.646
    36.295    25.672
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.286    25.641
    36.284    25.639
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.240    25.629
    36.284    25.639
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.300    25.630
    36.298    25.628
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.249    25.615
    36.298    25.628
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.476    25.785
    36.475    25.785
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.486    25.806
    36.475    25.785
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.267    25.615
    36.267    25.616
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.234    25.625
    36.267    25.616
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.526    25.477
    36.525    25.479
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.526    25.490
    36.525    25.479
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.472    25.531
    36.473    25.533
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.447    25.402
    36.473    25.533
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.603    25.606
    36.603    25.606
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.592    25.591
    36.603    25.606
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.532    25.494
    36.531    25.496
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.463    25.455
    36.531    25.496
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.548    25.506
    36.549    25.506
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.511    25.478
    36.549    25.506
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.510    25.510
    36.510    25.511
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.486    25.524
    36.510    25.511
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.526    25.530
    36.526    25.529
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.512    25.522
    36.526    25.529
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.539    25.499
    36.539    25.499
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.509    25.526
    36.539    25.499
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.528    25.517
    36.528    25.516
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.533    25.500
    36.528    25.516
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.538    25.506
    36.538    25.506
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.510    25.494
    36.538    25.506
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.504    25.506
    36.504    25.505
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.478    25.522
    36.504    25.505
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.525    25.454
    36.525    25.454
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.477    25.408
    36.525    25.454
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.617    25.730
    36.617    25.728
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.631    25.722
    36.617    25.728
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.510    25.514
    36.512    25.516
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.505    25.536
    36.512    25.516
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.267    25.642
    36.267    25.643
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.234    25.640
    36.267    25.643
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.647    25.662
    36.652    25.658
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.654    25.667
    36.652    25.658
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.646    25.632
    36.646    25.631
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.456    25.721
    36.646    25.631
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.604    25.615
    36.604    25.615
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.596    25.639
    36.604    25.615
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.605    25.674
    36.604    25.674
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.329    25.562
    36.604    25.674
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.593    25.667
    36.593    25.666
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.597    25.615
    36.593    25.666
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.624    25.723
    36.624    25.723
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.630    25.671
    36.624    25.723
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.623    25.695
    36.622    25.696
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.555    25.676
    36.622    25.696
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.600    25.715
    36.600    25.715
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.536    25.628
    36.600    25.715
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.613    25.695
    36.611    25.700
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.573    25.532
    36.611    25.700
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.605    25.736
    36.605    25.735
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.613    25.550
    36.605    25.735
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.587    25.722
    36.588    25.722
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.603    25.581
    36.588    25.722
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.614    25.706
    36.614    25.706
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.537    25.643
    36.614    25.706
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.595    25.751
    36.595    25.750
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.599    25.641
    36.595    25.750
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.600    25.692
    36.600    25.691
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.610    25.614
    36.600    25.691
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.598    25.720
    36.598    25.720
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.608    25.639
    36.598    25.720
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.627    25.745
    36.627    25.744
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.638    25.666
    36.627    25.744
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.617    25.747
    36.616    25.747
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.617    25.686
    36.616    25.747
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.614    25.692
    36.614    25.692
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.611    25.704
    36.614    25.692
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.615    25.703
    36.616    25.700
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.623    25.657
    36.616    25.700
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.596    25.693
    36.598    25.691
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.613    25.684
    36.598    25.691
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.630    25.712
    36.630    25.711
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.609    25.650
    36.630    25.711
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.645    25.718
    36.644    25.718
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.767    25.622
    36.644    25.718
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.650    25.764
    36.650    25.764
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.651    25.692
    36.650    25.764
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.654    25.693
    36.652    25.695
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.600    25.615
    36.652    25.695
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.666    25.760
    36.666    25.759
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.662    25.685
    36.666    25.759
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.641    25.768
    36.642    25.767
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.543    25.651
    36.642    25.767
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.621    25.724
    36.621    25.725
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.640    25.643
    36.621    25.725
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.616    25.710
    36.616    25.710
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.534    25.631
    36.616    25.710
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.628    25.693
    36.628    25.694
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.582    25.636
    36.628    25.694
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.630    25.729
    36.630    25.729
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.632    25.655
    36.630    25.729
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.642    25.747
    36.642    25.746
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.655    25.648
    36.642    25.746
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.653    25.723
    36.653    25.723
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.578    25.667
    36.653    25.723
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.652    25.773
    36.652    25.773
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.620    25.789
    36.652    25.773
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.667    25.712
    36.666    25.713
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.654    25.660
    36.666    25.713
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.599    25.675
    36.599    25.675
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.472    25.497
    36.599    25.675
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.592    25.677
    36.591    25.676
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.457    25.572
    36.591    25.676
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.612    25.657
    36.612    25.656
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.625    25.608
    36.612    25.656
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.616    25.699
    36.615    25.699
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.543    25.594
    36.615    25.699
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.631    25.793
    36.631    25.793
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.638    25.667
    36.631    25.793
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.655    25.744
    36.655    25.744
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.660    25.674
    36.655    25.744
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.652    25.775
    36.653    25.773
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.655    25.683
    36.653    25.773
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.650    25.791
    36.650    25.790
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.653    25.677
    36.650    25.790
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.679    25.719
    36.679    25.719
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.684    25.665
    36.679    25.719
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.641    25.715
    36.641    25.715
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.646    25.630
    36.641    25.715
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.639    25.724
    36.639    25.723
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.634    25.698
    36.639    25.723
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.649    25.773
    36.649    25.772
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.646    25.693
    36.649    25.772
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.644    25.737
    36.645    25.736
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.644    25.671
    36.645    25.736
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.633    25.711
    36.633    25.711
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.635    25.643
    36.633    25.711
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.662    25.794
    36.662    25.793
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.677    25.691
    36.662    25.793
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.659    25.781
    36.659    25.780
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.663    25.712
    36.659    25.780
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.596    25.691
    36.596    25.690
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.591    25.631
    36.596    25.690
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.596    25.620
    36.596    25.619
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.595    25.669
    36.596    25.619
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.601    25.693
    36.602    25.692
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.599    25.607
    36.602    25.692
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.616    25.699
    36.616    25.698
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.612    25.605
    36.616    25.698
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.587    25.692
    36.588    25.693
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.594    25.610
    36.588    25.693
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.605    25.693
    36.605    25.693
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.606    25.633
    36.605    25.693
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.603    25.667
    36.603    25.667
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.598    25.624
    36.603    25.667
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.612    25.688
    36.612    25.688
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.608    25.608
    36.612    25.688
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.625    25.619
    36.625    25.618
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.614    25.629
    36.625    25.618
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.610    25.690
    36.610    25.690
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.616    25.606
    36.610    25.690
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.595    25.643
    36.595    25.643
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.592    25.596
    36.595    25.643
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.602    25.713
    36.602    25.713
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.613    25.596
    36.602    25.713
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.595    25.773
    36.595    25.773
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.611    25.647
    36.595    25.773
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.582    25.628
    36.584    25.626
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.593    25.606
    36.584    25.626
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.637    25.780
    36.636    25.780
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.510    25.640
    36.636    25.780
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    36.534    25.614
    36.532    25.616
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    36.390    25.540
    36.532    25.616
END

# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    36.495    25.780    -5.936     2.305     4.532
    36.630    25.713   -58.383     3.853     4.968
    36.833    25.829   -65.431     3.122     4.002
    36.508    25.806    63.105     3.490     4.066
    36.603    25.885   -41.706     3.688     4.594
    36.582    25.683   -23.104     5.269     8.938
    36.641    25.761   -43.892     7.375    11.137
    36.614    25.734   -13.816     5.473     8.934
    36.702    25.888   -48.957     5.482     7.581
    36.739    25.900    30.286     1.660     2.337
    36.672    25.646   -37.794     2.078     3.144
    36.630    25.649   -86.203     4.484     5.358
    36.529    25.516   -71.502     1.802     2.413
    36.500    25.504   -30.763     2.148     2.489
    36.517    25.499    -1.036     2.175     2.522
    36.596    25.637   -27.315     2.998     3.738
    36.615    25.595   -38.062     2.824     3.633
    36.524    25.484   -82.900     2.705     2.908
    36.565    25.509   -60.559     1.418     2.073
    36.703    25.744    -0.104     3.653     4.100
    36.542    25.488   -72.218     2.183     2.943
    36.642    25.818    82.536     1.873     2.052
    36.661    25.868    79.519     2.315     2.421
    36.545    25.498    22.873     1.441     2.439
    36.530    25.492     3.610     1.360     2.190
    36.707    25.979    89.225     3.640     3.988
    36.511    25.498    16.979     1.990     3.171
    36.537    25.502     2.395     1.155     2.028
    36.692    25.656    28.338     1.924     2.974
    36.521    25.495    18.962     1.093     1.359
    36.520    25.506    16.367     0.997     1.218
    36.529    25.506    53.377     0.715     0.777
    36.531    25.508    -5.328     1.489     2.544
    36.521    25.479    18.614     1.210     1.797
    36.547    25.523    12.372     0.982     1.470
    36.536    25.533    22.012     1.233     1.699
    36.540    25.511   -73.424     0.749     0.852
    36.542    25.510     1.407     1.589     2.606
    36.548    25.491    20.159     1.812     2.903
    36.608    25.678    52.918     0.964     1.356
    36.689    25.755    27.400     0.995     1.394
    36.636    25.713    40.343     0.995     1.640
    36.693    25.738    23.528     0.962     1.567
    36.690    25.913    40.088     0.835     1.296
    36.521    25.500    26.466     0.963     1.301
    36.618    25.701    42.067     0.748     1.422
    36.610    25.730    30.474     0.890     1.416
    36.611    25.708    31.800     1.054     1.539
    36.533    25.536    14.213     0.978     1.524
    36.541    25.501    15.530     0.983     1.266
    36.599    25.605    33.051     0.953     1.695
    36.587    25.704    52.471     0.828     1.122
    36.603    25.676    35.588     1.292     1.968
    36.724    25.632    45.710     0.947     1.428
    36.600    25.693    42.398     1.229     2.194
    36.580    25.683    44.788     1.137     1.464
    36.656    25.737    55.512     1.158     1.841
    36.651    25.765    55.354     0.975     1.562
    36.659    25.735    49.515     1.119     2.065
    36.655    25.772    72.889     0.815     1.013
    36.663    25.768    68.001     0.756     1.361
    36.656    25.767    72.696     0.733     1.183
    36.660    25.764    49.162     1.089     1.800
    36.668    25.759    34.341     1.371     1.998
    36.669    25.746    48.026     1.476     1.937
    36.658    25.747    45.688     1.248     1.994
    36.697    25.610    33.009     1.769     2.678
    36.679    25.643    59.627     1.471     2.000
    36.694    25.681    26.422     1.002     1.563
    36.585    25.696    27.891     1.404     1.845
    36.502    25.768    67.824     1.116     2.133
    36.522    25.709    58.873     1.792     2.297
    36.295    25.672   -71.356     0.847     1.555
    36.284    25.639   -62.541     0.867     1.421
    36.298    25.628   -54.971     1.050     1.464
    36.475    25.785    67.810     2.813     5.373
    36.267    25.616   -41.508     1.537     3.065
    36.525    25.479    -6.878     1.356     3.362
    36.473    25.533    23.159     1.785     2.529
    36.603    25.606    31.566     0.859     1.259
    36.531    25.496     5.181     0.946     1.289
    36.549    25.506    -0.243     1.483     2.906
    36.510    25.511    24.661     0.914     1.202
    36.526    25.529     8.801     0.751     1.179
    36.539    25.499     1.578     1.143     2.550
    36.528    25.516    32.904     1.050     1.968
    36.538    25.506    14.476     0.823     1.048
    36.504    25.505     1.763     1.047     1.668
    36.525    25.454    12.077     1.332     2.088
    36.617    25.728    35.753     0.752     1.125
    36.512    25.516     1.445     0.771     1.405
    36.267    25.643   -28.767     1.225     1.769
    36.652    25.658    34.490     1.111     1.393
    36.646    25.631    22.367     1.547     3.066
    36.604    25.615    16.190     2.382     9.795
    36.604    25.674    25.087     2.245     5.704
    36.593    25.666    21.424     1.747     4.215
    36.624    25.723    23.679     1.514     3.243
    36.622    25.696    30.887     1.477     2.212
    36.600    25.715    26.351     1.484     3.259
    36.611    25.700    21.942     1.523     2.891
    36.605    25.735    19.575     1.616     5.369
    36.588    25.722    27.443     2.096     4.500
    36.614    25.706    24.081     1.649     3.739
    36.595    25.750    36.714     2.861     5.750
    36.600    25.691    17.962     1.871     4.486
    36.598    25.720    25.236     1.720     3.666
    36.627    25.744    21.592     2.310     4.847
    36.616    25.747    21.058     1.991     3.862
    36.614    25.692    30.828     1.961     2.691
    36.616    25.700    34.195     1.364     2.052
    36.598    25.691    35.220     1.463     2.223
    36.630    25.711    25.341     1.182     2.526
    36.644    25.718    22.442     1.288     2.891
    36.650    25.764    29.487     2.333     4.727
    36.652    25.695    29.532     1.265     1.786
    36.666    25.759    19.027     2.755     6.944
    36.642    25.767    27.272     1.488     2.739
    36.621    25.725    25.387     1.933     5.246
    36.616    25.710    39.323     1.626     2.327
    36.628    25.694    26.941     1.206     1.723
    36.630    25.729    13.208     2.133     4.971
    36.642    25.746    23.305     1.683     3.097
    36.653    25.723    25.377     1.489     3.092
    36.652    25.773    20.939     1.785     3.847
    36.666    25.713    20.669     1.717     3.684
    36.599    25.675    21.121     1.545     3.164
    36.591    25.676    38.683     1.708     2.240
    36.612    25.656    19.717     1.866     4.890
    36.615    25.699    20.688     1.830     4.566
    36.631    25.793    27.344     2.967     6.227
    36.655    25.744    19.648     1.721     3.755
    36.653    25.773    29.013     1.647     3.058
    36.650    25.790    28.514     2.091     4.099
    36.679    25.719    20.304     1.274     2.597
    36.641    25.715    16.416     1.877     5.603
    36.639    25.723    21.579     1.387     2.207
    36.649    25.772    22.644     2.149     4.216
    36.645    25.736    15.908     1.625     3.865
    36.633    25.711    18.945     1.833     4.339
    36.662    25.793    14.079     2.049     4.311
    36.659    25.780    26.230     1.536     2.699
    36.596    25.690    17.700     2.218     3.666
    36.596    25.619    13.022     2.570     7.391
    36.602    25.692    17.651     1.901     4.466
    36.616    25.698     9.743     1.889     2.485
    36.588    25.693    17.942     2.943     7.012
    36.605    25.693     7.501     1.719     2.616
    36.603    25.667    13.452     1.645     3.857
    36.612    25.688     9.747     1.926     2.709
    36.625    25.618     9.620     1.889     5.563
    36.610    25.690    19.026     1.818     4.032
    36.595    25.643    17.100     1.951     3.563
    36.602    25.713    24.649     1.532     2.616
    36.595    25.773    28.090     2.466     4.779
    36.584    25.626    13.244     1.653     3.201
    36.636    25.780    26.197     1.712     2.882
    36.532    25.616    17.016     2.097     3.721
END

# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    36.495    25.780     0.300
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    36.221    25.421    25.138     0.707     1.472
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    36.221    25.444   Hypocentroid
END

# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    36.221    25.421     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    36.221    25.421     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    36.176    25.421   5 km
END
